@@ -20,15 +20,21 @@ struct _GingerblueData {
 	gchar *label;
 	gboolean lpf;
 	gboolean hpf;
+	gchar *musician;
+	gchar *musical_instrument;
 	gchar *version;
 	gchar *volume;
 	GingerblueData *next;
 	GingerblueData *prev;
 };
 
-/* gdouble gb_window_set_volume (GtkVolumeButton *volume, gpointer value); */
+void gb_window_break_record (GtkButton *record, GtkVolumeButton *volume);
+void gb_window_pause_record (GtkButton *record, GtkVolumeButton *volume);
+GingerblueData *gb_window_new_record (GtkButton *record, GtkVolumeButton *volume);
+GingerblueData *gb_window_store_volume (GtkButton *record, GtkVolumeButton *volume);
+gdouble gb_window_set_volume (GtkVolumeButton *volume, gdouble value);
 gdouble gb_window_new_volume (GtkVolumeButton *volume, gchar *msg);
-/* gdouble gb_window_get_volume (GtkVolumeButton *volume, gpointer value); */
+gdouble gb_window_get_volume (GtkVolumeButton *volume);
 
 gint gb_exit (void);
 
